@@ -45,7 +45,7 @@ export PERL_MM_USE_DEFAULT PERL_MM_OPT
 
 # which extra modules to install by default from CPAN that are
 # required by mkbundle
-STATICPERL_MODULES="ExtUtils::MakeMaker common::sense Pod::Strip PPI PPI::XS Pod::Usage"
+STATICPERL_MODULES="ExtUtils::MakeMaker ExtUtils::CBuilder common::sense Pod::Strip PPI PPI::XS Pod::Usage"
 
 # which extra modules you might want to install
 EXTRA_MODULES=""
@@ -69,6 +69,13 @@ fi
 #############################################################################
 # support
 
+# work around ExtUtils::CBuilder and others
+export CC="$PERL_CC"
+export CFLAGS="$PERL_CFLASGS"
+export LD="$PERL_CC"
+export LDFLAGS="$PERL_LDFLAGS"
+unset LIBS
+
 PERL_PREFIX="${PERL_PREFIX:=$STATICPERL/perl}" # where the perl gets installed
 
 unset PERL5OPT PERL5LIB PERLLIB PERL_UNICODE PERLIO_DEBUG
@@ -81,7 +88,7 @@ PATH="$PERL_PREFIX/perl/bin:$PATH"
 
 # set version in a way that Makefile.PL can extract
 VERSION=VERSION; eval \
-$VERSION="1.43"
+$VERSION="1.44"
 
 BZ2=bz2
 BZIP2=bzip2
@@ -177,8 +184,8 @@ EOF
          mv $PERLTAR~ $PERLTAR
          if [ "$DLCACHE" ]; then
             mkdir -p "$DLCACHE"
-            cp $PERLTAR "$DLCACHE"/$PERLTAR~ && \
-               mv "$DLCACHE"/$PERLTAR~ "$DLCACHE"/$PERLTAR
+            cp $PERLTAR "$DLCACHE"/$PERLTAR~$$~ && \
+               mv "$DLCACHE"/$PERLTAR~$$~ "$DLCACHE"/$PERLTAR
          fi
       fi
 
@@ -336,7 +343,7 @@ _postinstall() {
    if ! [ -e "$PERL_PREFIX/staticstamp.postinstall" ]; then
       NOCHECK_INSTALL=+
       instcpan $STATICPERL_MODULES
-      [ $EXTRA_MODULES ] && instcpan $EXTRA_MODULES
+      [ "$EXTRA_MODULES" ] && instcpan $EXTRA_MODULES
 
       postinstall || fatal "postinstall hook failed"
 
@@ -375,6 +382,7 @@ EOF
 #CAT patch-postinstall.sh
 EOF
 
+      # immediately use it
       "$PERL_PREFIX/bin/SP-patch-postinstall"
 
       # help to trick CPAN into avoiding ~/.cpan completely
@@ -392,9 +400,10 @@ EOF
          CPAN::Shell->o (conf => q<prefs_dir>, "'"$STATICPERL"'/cpan/prefs");
          CPAN::Shell->o (conf => q<histfile> , "'"$STATICPERL"'/cpan/histfile");
          CPAN::Shell->o (conf => q<keep_source_where>, "'"$STATICPERL"'/cpan/sources");
+         CPAN::Shell->o (conf => q<makepl_arg>, "MAP_TARGET=perl");
          CPAN::Shell->o (conf => q<make_install_make_command>, "'"$PERL_PREFIX"'/bin/SP-make-install-make");
          CPAN::Shell->o (conf => q<prerequisites_policy>, q<follow>);
-         CPAN::Shell->o (conf => q<build_requires_install_policy>, q<no>);
+         CPAN::Shell->o (conf => q<build_requires_install_policy>, q<yes>);
          CPAN::Shell->o (conf => q<prefer_installer>, "EUMM");
          CPAN::Shell->o (conf => q<commit>);
       ' || fatal "error while initialising CPAN"
